==> oc-2.15.1.zip: oc/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%Y-%m-%d %H:%M'] = '%d lo %m de %Y %H:%M';
$GLOBALS['__l10n']['_Jan'] = 'Gen';
$GLOBALS['__l10n']['_Feb'] = 'Feb';
$GLOBALS['__l10n']['_Mar'] = 'Mar';
$GLOBALS['__l10n']['_Apr'] = 'Abr';
$GLOBALS['__l10n']['_May'] = 'Mai';
$GLOBALS['__l10n']['_Jun'] = 'Jun';
$GLOBALS['__l10n']['_Jul'] = 'Jul';
$GLOBALS['__l10n']['_Aug'] = 'Ago';
$GLOBALS['__l10n']['_Sep'] = 'Set';
$GLOBALS['__l10n']['_Oct'] = 'Oct';
$GLOBALS['__l10n']['_Nov'] = 'Nov';
$GLOBALS['__l10n']['_Dec'] = 'Dec';
$GLOBALS['__l10n']['January'] = 'Genièr';
$GLOBALS['__l10n']['February'] = 'Febrièr';
$GLOBALS['__l10n']['March'] = 'Març';
$GLOBALS['__l10n']['April'] = 'Abrial';
$GLOBALS['__l10n']['May'] = 'Mai';
$GLOBALS['__l10n']['June'] = 'Junh';
$GLOBALS['__l10n']['July'] = 'Julhet';
$GLOBALS['__l10n']['August'] = 'Agost';
$GLOBALS['__l10n']['September'] = 'Setembre';
$GLOBALS['__l10n']['October'] = 'Octobre';
$GLOBALS['__l10n']['November'] = 'Novembre';
$GLOBALS['__l10n']['December'] = 'Decembre';
$GLOBALS['__l10n']['_Mon'] = '';
$GLOBALS['__l10n']['_Tue'] = '';
$GLOBALS['__l10n']['_Wed'] = '';
$GLOBALS['__l10n']['_Thu'] = '';
$GLOBALS['__l10n']['_Fri'] = '';
$GLOBALS['__l10n']['_Sat'] = '';
$GLOBALS['__l10n']['_Sun'] = '';
$GLOBALS['__l10n']['Monday'] = 'Diluns';
$GLOBALS['__l10n']['Tuesday'] = 'Dimarç';
$GLOBALS['__l10n']['Wednesday'] = 'Dimècres';
$GLOBALS['__l10n']['Thursday'] = 'Dijòus';
$GLOBALS['__l10n']['Friday'] = 'Divendres';
$GLOBALS['__l10n']['Saturday'] = 'Dissabte';
$GLOBALS['__l10n']['Sunday'] = 'Dimenge';

==> oc-2.16.7.zip: oc/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['%Y-%m-%d %H:%M'] = '%d lo %m de %Y %H:%M';
$GLOBALS['__l10n']['_Jan'] = 'Gen';
$GLOBALS['__l10n']['_Feb'] = 'Feb';
$GLOBALS['__l10n']['_Mar'] = 'Mar';
$GLOBALS['__l10n']['_Apr'] = 'Abr';
$GLOBALS['__l10n']['_May'] = 'Mai';
$GLOBALS['__l10n']['_Jun'] = 'Jun';
$GLOBALS['__l10n']['_Jul'] = 'Jul';
$GLOBALS['__l10n']['_Aug'] = 'Ago';
$GLOBALS['__l10n']['_Sep'] = 'Set';
$GLOBALS['__l10n']['_Oct'] = 'Oct';
$GLOBALS['__l10n']['_Nov'] = 'Nov';
$GLOBALS['__l10n']['_Dec'] = 'Dec';
$GLOBALS['__l10n']['January'] = 'Genièr';
$GLOBALS['__l10n']['February'] = 'Febrièr';
$GLOBALS['__l10n']['March'] = 'Març';
$GLOBALS['__l10n']['April'] = 'Abrial';
$GLOBALS['__l10n']['May'] = 'Mai';
$GLOBALS['__l10n']['June'] = 'Junh';
$GLOBALS['__l10n']['July'] = 'Julhet';
$GLOBALS['__l10n']['August'] = 'Agost';
$GLOBALS['__l10n']['September'] = 'Setembre';
$GLOBALS['__l10n']['October'] = 'Octobre';
$GLOBALS['__l10n']['November'] = 'Novembre';
$GLOBALS['__l10n']['December'] = 'Decembre';
$GLOBALS['__l10n']['_Mon'] = 'Diluns';
$GLOBALS['__l10n']['_Tue'] = 'Dimars';
$GLOBALS['__l10n']['_Wed'] = 'Dimècres';
$GLOBALS['__l10n']['_Thu'] = 'Dijòus';
$GLOBALS['__l10n']['_Fri'] = 'Divendres';
$GLOBALS['__l10n']['_Sat'] = 'Dissabte';
$GLOBALS['__l10n']['_Sun'] = 'Dimenge';
$GLOBALS['__l10n']['Monday'] = 'Diluns';
$GLOBALS['__l10n']['Tuesday'] = 'Dimars';
$GLOBALS['__l10n']['Wednesday'] = 'Dimècres';
$GLOBALS['__l10n']['Thursday'] = 'Dijòus';
$GLOBALS['__l10n']['Friday'] = 'Divendres';
$GLOBALS['__l10n']['Saturday'] = 'Dissabte';
$GLOBALS['__l10n']['Sunday'] = 'Dimenge';
